# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class SearchWeb(BaseModel):
    search_web: Optional["SearchWebSearchWeb"] = Field(alias="searchWeb")


class SearchWebSearchWeb(BaseModel):
    results: Optional[List["SearchWebSearchWebResults"]]


class SearchWebSearchWebResults(BaseModel):
    uri: Any
    text: Optional[str]
    title: Optional[str]
    score: Optional[float]


SearchWeb.model_rebuild()
SearchWebSearchWeb.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class EnableFeed(BaseModel):
    enable_feed: Optional["EnableFeedEnableFeed"] = Field(alias="enableFeed")


class EnableFeedEnableFeed(BaseModel):
    id: str
    state: EntityState


EnableFeed.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalDrugClass(BaseModel):
    delete_medical_drug_class: Optional[
        "DeleteMedicalDrugClassDeleteMedicalDrugClass"
    ] = Field(alias="deleteMedicalDrugClass")


class DeleteMedicalDrugClassDeleteMedicalDrugClass(BaseModel):
    id: str
    state: EntityState


DeleteMedicalDrugClass.model_rebuild()
